Steps to run this script:
1. Create a copy of template.env and name it as .env
2. Fill in the variables in .env file
3. Execute the command given below to grant executable permission to the script.
~~~
chmod +x apidocs.sh
~~~
4. To run the script use this command:
~~~
./apidocs.sh <path to repo>
~~~

**Note**:
This script is not supported on Windows.